
Keras Piecewise
===============


.. image:: https://travis-ci.org/CyberZHG/keras-pos-embd.svg
   :target: https://travis-ci.org/CyberZHG/keras-pos-embd
   :alt: Travis


.. image:: https://coveralls.io/repos/github/CyberZHG/keras-pos-embd/badge.svg?branch=master
   :target: https://coveralls.io/github/CyberZHG/keras-pos-embd
   :alt: Coverage


.. image:: https://img.shields.io/pypi/pyversions/keras-pos-embd.svg
   :target: https://pypi.org/project/keras-pos-embd/
   :alt: PyPI


Position embedding layers in Keras.

Install
-------

.. code-block:: bash

   pip install keras-pos-embd

Usage
-----

``python``
